package com.muyu.domain.req;

import com.muyu.common.core.validation.custom.IsSystemYesNo;
import io.swagger.v3.oas.annotations.media.Schema;
import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.NotEmpty;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class OrderCustomerUpdReq {

    /**
     * 服务/客户名称
     */
    @NotEmpty(message = "服务客户名称不可为空")
    @Schema(title = "服务/客户名称", type = "String", defaultValue = "会员服务",
            description = "客户名称为微服务的中文名称", requiredProperties = {"appName"})
    private String appName;

    /**
     * 服务/客户描述
     */
    @Schema(title = "服务/客户描述", type = "String")
    private String appDesc;

    /**
     * 状态
     */
    @NotBlank(message = "客户使用状态不可为空")
    @IsSystemYesNo
    @Schema(title = "服务/客户开通状态", type = "String", defaultValue = "Y",
            description = "状态为Y和N，如果为Y则客户可以使用支付接口，若为N则客户不可以使用支付类接口")
    private String status;

    /**
     * 客户备注
     */
    @Schema(title = "服务/客户备注", type = "String")
    private String remark;
}
