package com.muyu.domain.resp;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.muyu.domain.OrderPayCustomer;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.util.Date;
import java.util.List;
import java.util.function.Function;
import java.util.function.Supplier;


@AllArgsConstructor
@Data
@NoArgsConstructor
@Builder
@Tag(name = "客户信息相应对象",description = "负责客户信息查询结果")
public class CustomerResp {

    /**
     * 主键自增
     */
    @Schema(type = "Long" , defaultValue = "ID" , description = "客户名称，为微服务中文名称")
    private Long id;

    /**
     * 服务/客户名称
     */
    @Schema(defaultValue = "客户名称",type = "String" , description = "客户名称")
    private String appName;

    /**
     * 服务/客户编号
     */
    @Schema(type = "String" , description = "客户的编码")
    private String appCode;

    /**
     * 客户描述
     */
    @Schema(type = "String" , description = "客户名称")
    private String appDesc;

    /**
     * 是否开启
     */
    @Schema(type = "String" , description = "客户状态")
    private String status;

    @Schema(type = "String" , description = "muyu")
    private String createBy;

    @Schema(type = "String" , description = "创建时间")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private Date createTime;



    private List<CustomerOrderPaySimpleResp> orderPaySimpleRespList;


    /**
     * 返回结果
     */
    public static CustomerResp customerBuild (OrderPayCustomer orderPayCustomer, Supplier<List<CustomerOrderPaySimpleResp>> function) {
        return CustomerResp.builder()
                .id(orderPayCustomer.getId())
                .appName(orderPayCustomer.getAppName())
                .appCode(orderPayCustomer.getAppCode())
                .status(orderPayCustomer.getStatus())
                .createBy(orderPayCustomer.getCreateBy())
                .createTime(orderPayCustomer.getCreateTime())
                .orderPaySimpleRespList(function.get())
                .build();
    }
}
